cmd

package
v0.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 21, 2026 License: MIT Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var AddBookmarkCmd = &cobra.Command{
	Use:   "add <name> <path/url>",
	Short: "Add a new bookmark",
	RunE:  add,
}
var ClearBookmarksCmd = &cobra.Command{
	Use:   "clear",
	Short: "Remove all bookmarks",
	RunE:  clear,
}
var CopyBookmarkCmd = &cobra.Command{
	Use:   "copy <name>",
	Short: "Copy the bookmark target to the clipboard",
	RunE:  copyCmd,
}
var DedupCmd = &cobra.Command{
	Use:   "dedup",
	Short: "Find and interactively remove duplicate bookmark targets",
	RunE:  dedupCmd,
}
var EditBookmarkCmd = &cobra.Command{
	Use:   "edit <name> [flags]",
	Short: "edits the content of a bookmark",
	RunE:  edit,
}
var ExportBookmarksCmd = &cobra.Command{
	Use:   "export <path>",
	Short: "Export saved bookmarks to a file",
	RunE:  export,
}
var GroupCmd = &cobra.Command{
	Use:   "group <add|remove|open|list>",
	Short: "Manage bookmark groups",
	RunE: func(cmd *cobra.Command, args []string) error {
		_ = cmd.Help()
		return nil
	},
}
var ImportBookmarksCmd = &cobra.Command{
	Use:   "import <path>",
	Short: "Import bookmarks from a file, replacing the current set",
	RunE:  importBookmarks,
}
var InstallCmd = &cobra.Command{
	Use:   "install <shell> <show|apply>",
	Short: "prints or installs the shell wrapper in order for opening paths to work",
	RunE:  install,
}
var ListBookmarksCmd = &cobra.Command{
	Use:   "list",
	Short: "Lists all bookmarks",

	RunE: list,
}
var OpenBookmarkCmd = &cobra.Command{
	Use:   "open <name>",
	Short: "opens the bookmark with the default browser/editor or cd's into the directory",
	RunE:  openCmd,
}
var PinBookmarkCmd = &cobra.Command{
	Use:   "pin <name>",
	Short: "Toggle the pinned state of a bookmark",
	RunE:  pinCmd,
}
var RecentBookmarksCmd = &cobra.Command{
	Use:   "recent",
	Short: "Show the most recently accessed bookmarks",
	RunE:  recentCmd,
}
var RemoveBookmarkCmd = &cobra.Command{
	Use:   "remove <name>",
	Short: "Remove a bookmark",

	RunE: remove,
}
var RenameBookmarkCmd = &cobra.Command{
	Use:   "rename <old> <new>",
	Short: "Rename a bookmark",
	RunE:  renameCmd,
}
var SearchBookmarksCmd = &cobra.Command{
	Use:   "search <query>",
	Short: "Full-text search across name, tags, and notes",
	RunE:  searchCmd,
}
var StatsCmd = &cobra.Command{
	Use:   "stats",
	Short: "Show usage statistics",
	RunE:  statsCmd,
}

Functions

func Execute

func Execute()

Types

This section is empty.

Jump to